# fast-ft（Fast File Transfer）

fast-ft 是一个精简的文件传输工具，做到安装即用，无需任何配置，操作简单快捷，是开发者局域网内文件传输的好帮手。

Fast-ft is a simple file transfer tool, which can be installed and used without any configuration. It is a good helper for developers to transfer files in LAN.

精简，精简到两个页面，一个上传一个下载，做传输工具最重要的目标是稳定可靠的实现传输。

Simplify, simplify to two pages, one upload and one download, the most important goal of transmission tool is stable and reliable transmission.

便捷，无需任何配置操作，只要电脑中有python，在全局安装一个包就可以在命令行中快速启动网站，网站首页自动打开，提供二维码供其他移动设备快速访问。

Convenient, without any configuration operation, as long as there is Python in the computer, you can quickly start the website in the command line by installing a package in the global, and the homepage of the website will automatically open, providing two-dimensional code for other mobile devices to quickly access.

缓解，开发者不再需要依赖社交应用（QQ、微信)来完成局域网内文件传输，也不用因为找不到数据线这种传统介质而着急上火，只要你电脑里安装了python就能非常方便的传输文件。

Ease, developers no longer need to rely on social applications (QQ, wechat) to complete the file transfer within the LAN, and they don't need to be anxious because they can't find the traditional media such as data cable. As long as you install Python in your computer, you can easily transfer files.


## 目的

* 



## 安装

* 通过<code>pip install -r requirements</code>安装所需包  


## 运行

* 



## 效果

* [bilibili效果演示](https://www.bilibili.com/video/BV1SK4y1D7Zt)



## 技术

* 



## 未来

* 



## 致谢

* [感谢开源项目](https://github.com/lsm1103/pyupload)
